@@ -12,6 +12,7 @@ import (
 	"strconv"
 	"strings"
 	"syscall"
+	"net/url"
 
 	"github.com/golang/protobuf/proto"
 
@@ -54,7 +55,7 @@ var (
 	remotePort  = flag.String("remotePort", "1080", "remote port to forward.")
 	path        = flag.String("path", "/", "URL path for websocket.")
 	serviceName = flag.String("serviceName", "GunService", "Service name for grpc.")
-	host        = flag.String("host", "cloudflare.com", "Hostname for server.")
+	host        = flag.String("host", "cloudfront.com", "Hostname for server.")
 	tlsEnabled  = flag.Bool("tls", false, "Enable TLS.")
 	cert        = flag.String("cert", "", "Path to TLS certificate file. Overrides certRaw. Default: ~/.acme.sh/{host}/fullchain.cer")
 	certRaw     = flag.String("certRaw", "", "Raw TLS certificate content. Intended only for Android.")
@@ -136,11 +137,22 @@ func generateConfig() (*core.Config, error) {
 	var connectionReuse bool
 	switch *mode {
 	case "websocket":
+		var ed uint32
+		if u, err := url.Parse(*path); err == nil {
+			if q := u.Query(); q.Get("ed") != "" {
+				Ed, _ := strconv.Atoi(q.Get("ed"))
+				ed = uint32(Ed)
+				q.Del("ed")
+				u.RawQuery = q.Encode()
+				*path = u.String()
+			}
+		}
 		transportSettings = &websocket.Config{
 			Path: *path,
 			Header: []*websocket.Header{
 				{Key: "Host", Value: *host},
 			},
+			Ed: ed,
 		}
 		if *mux != 0 {
 			connectionReuse = true
@@ -252,7 +264,7 @@ func generateConfig() (*core.Config, error) {
 	} else {
 		senderConfig := proxyman.SenderConfig{StreamSettings: &streamConfig}
 		if connectionReuse {
-			senderConfig.MultiplexSettings = &proxyman.MultiplexingConfig{Enabled: true, Concurrency: uint32(*mux)}
+			senderConfig.MultiplexSettings = &proxyman.MultiplexingConfig{Enabled: true, Concurrency: int32(*mux)}
 		}
 		return &core.Config{
 			Inbound: []*core.InboundHandlerConfig{{
